@@ -14,7 +14,9 @@ class RedisStore(object):
 
     DEFAULT_TTL = 5 * 60  # seconds
 
-    def __init__(self, host='localhost', port=6379, db=0,
+    def __init__(self, host='localhost', port=6379, db=0, password=None,
+            socket_timeout=None, connection_pool=None, charset='utf-8',
+            errors='strict', decode_responses=False, unix_socket_path=None,
             ttl=DEFAULT_TTL):
         self.ttl = ttl
         try:
@@ -22,7 +24,11 @@ class RedisStore(object):
         except ImportError:
             raise RuntimeError('Redis support is not available. Run "pip install redis".')
 
-        self.redis = Redis(host=host, port=port, db=db)
+        self.redis = Redis(host=host, port=port, db=db,
+                password=password, socket_timeout=socket_timeout,
+                connection_pool=connection_pool, charset=charset,
+                errors=errors, decode_responses=decode_responses,
+                unix_socket_path=unix_socket_path)
 
     def __getitem__(self, key):
         entry = self.redis.get(key)
