@@ -18,6 +18,8 @@ class Provider(Resource, DeleteMixin, DictMixin, SaveMixin):
 
     GOOGLE = 'google'
     FACEBOOK = 'facebook'
+    GITHUB = 'GITHUB'
+    LINKEDIN = 'linkedin'
     STORMPATH = 'stormpath'
 
     writable_attrs = (
@@ -26,3 +28,11 @@ class Provider(Resource, DeleteMixin, DictMixin, SaveMixin):
         'redirect_uri',
         'provider_id',
     )
+
+    def save(self):
+        if self.provider_id == self.STORMPATH:
+            return
+        if self.is_new():
+            raise ValueError("Can't save new resources, use create instead")
+
+        self._store.update_resource(self.href, self._get_properties())
